@@ -71,8 +71,14 @@ class BalderQuery(metaclass=BalderQueryMeta):
         assert issubclass(meta.type, DjangoObjectType), "You cannot use Query without a custom resolver if it is not a DjangoObjectType"
         qs = meta.queryset or meta.type._meta.model._default_manager.get_queryset()
 
-        list_resolver = lambda root, info, *args, **kwargs: qs.all()
-        item_resolver = lambda root, info, *args, **kwargs: qs.first()
+        if meta.personal:
+            # Personal means we want to filter the queryset for the user with that fied
+            assert isinstance(meta.personal, str), "Meta attribute personal must be of type str"
+            list_resolver = lambda root, info, *args, **kwargs: qs.filter(**{meta.personal: info.context.user})
+            item_resolver = lambda root, info, *args, **kwargs: qs.filter(**{meta.personal: info.context.user}).first()
+        else:
+            list_resolver = lambda root, info, *args, **kwargs: qs.all()
+            item_resolver = lambda root, info, *args, **kwargs: qs.first()
 
         if meta.filter:
             if issubclass(meta.filter, django_filters.FilterSet):
